@@ -87,6 +87,10 @@
                                   @"kVLCVideoLibraryGridLayoutALL_VIDEOS" : @(YES),
                                   @"kVLCVideoLibraryGridLayoutVIDEO_GROUPS" : @(YES),
                                   @"kVLCVideoLibraryGridLayoutVLCMLMediaGroupCollections" : @(YES),
+                                  kVLCPlayerShouldRememberState: @(YES),
+                                  kVLCPlayerIsShuffleEnabled: kVLCPlayerIsShuffleEnabledDefaultValue,
+                                  kVLCPlayerIsRepeatEnabled: kVLCPlayerIsRepeatEnabledDefaultValue,
+                                  kVLCSettingPlaybackSpeedDefaultValue: @(1.0)
     };
     [defaults registerDefaults:appDefaults];
 }
